==> jgiven-core-0.4.0-sources.jar: com/tngtech/jgiven/report/model/StatisticsCalculator.java <==
package com.tngtech.jgiven.report.model;

import java.util.List;

public class StatisticsCalculator {

    public ReportStatistics getStatistics( ReportModel model ) {
        ReportStatistics result = new ReportStatistics();
        model.accept( new StatisticsVisitor( result ) );
        return result;
    }

    public ReportStatistics getStatistics( List<ScenarioModel> models ) {
        ReportStatistics result = new ReportStatistics();
        for( ScenarioModel model : models ) {
            model.accept( new StatisticsVisitor( result ) );
        }
        return result;
    }

    private static class StatisticsVisitor extends ReportModelVisitor {
        final ReportStatistics statistics;

        public StatisticsVisitor( ReportStatistics statistics ) {
            this.statistics = statistics;
        }

        @Override
        public void visit( ReportModel reportModel ) {
            statistics.numClasses++;
        }

        @Override
        public void visit( ScenarioModel scenarioModel ) {
            statistics.numScenarios++;
            statistics.durationInNanos += scenarioModel.getDurationInNanos();
        }

        @Override
        public void visit( ScenarioCaseModel scenarioCase ) {
            statistics.numCases++;
            if( !scenarioCase.success ) {
                statistics.numFailedCases++;
            }
        }

        @Override
        public void visit( StepModel methodModel ) {
            statistics.numSteps++;
        }

    }

}

==> jgiven-core-0.5.3-sources.jar: com/tngtech/jgiven/report/model/StatisticsCalculator.java <==
package com.tngtech.jgiven.report.model;

import java.util.List;

public class StatisticsCalculator {

    public ReportStatistics getStatistics( ReportModel model ) {
        ReportStatistics result = new ReportStatistics();
        model.accept( new StatisticsVisitor( result ) );
        return result;
    }

    public ReportStatistics getStatistics( List<ScenarioModel> models ) {
        ReportStatistics result = new ReportStatistics();
        for( ScenarioModel model : models ) {
            model.accept( new StatisticsVisitor( result ) );
        }
        return result;
    }

    private static class StatisticsVisitor extends ReportModelVisitor {
        final ReportStatistics statistics;

        public StatisticsVisitor( ReportStatistics statistics ) {
            this.statistics = statistics;
        }

        @Override
        public void visit( ReportModel reportModel ) {
            statistics.numClasses++;
        }

        @Override
        public void visit( ScenarioModel scenarioModel ) {
            statistics.numScenarios++;
            statistics.durationInNanos += scenarioModel.getDurationInNanos();
            ExecutionStatus executionStatus = scenarioModel.getExecutionStatus();
            if( executionStatus == ExecutionStatus.FAILED ) {
                statistics.numFailedScenarios += 1;
            } else if( executionStatus == ExecutionStatus.NONE_IMPLEMENTED || executionStatus == ExecutionStatus.PARTIALLY_IMPLEMENTED ) {
                statistics.numPendingScenarios += 1;
            } else {
                statistics.numSuccessfulScenarios += 1;
            }
        }

        @Override
        public void visit( ScenarioCaseModel scenarioCase ) {
            statistics.numCases++;
            if( !scenarioCase.success ) {
                statistics.numFailedCases++;
            }
        }

        @Override
        public void visit( StepModel methodModel ) {
            statistics.numSteps++;
        }

    }

}
